==> volcano-model-v1beta1-6.8.1-sources.jar: io/fabric8/volcano/scheduling/v1beta1/QueueStatusFluent.java <==
package io.fabric8.volcano.scheduling.v1beta1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class QueueStatusFluent<A extends QueueStatusFluent<A>> extends BaseFluent<A>{
  public QueueStatusFluent() {
  }
  public QueueStatusFluent(QueueStatus instance) {
    instance = (instance != null ? instance : new QueueStatus());

    if (instance != null) {
      this.withInqueue(instance.getInqueue());
      this.withPending(instance.getPending());
      this.withRunning(instance.getRunning());
      this.withState(instance.getState());
      this.withUnknown(instance.getUnknown());
      this.withInqueue(instance.getInqueue());
      this.withPending(instance.getPending());
      this.withRunning(instance.getRunning());
      this.withState(instance.getState());
      this.withUnknown(instance.getUnknown());
    }
  }
  private Integer inqueue;
  private Integer pending;
  private Integer running;
  private String state;
  private Integer unknown;
  public Integer getInqueue() {
    return this.inqueue;
  }
  public A withInqueue(Integer inqueue) {
    this.inqueue=inqueue; return (A) this;
  }
  public boolean hasInqueue() {
    return this.inqueue != null;
  }
  public Integer getPending() {
    return this.pending;
  }
  public A withPending(Integer pending) {
    this.pending=pending; return (A) this;
  }
  public boolean hasPending() {
    return this.pending != null;
  }
  public Integer getRunning() {
    return this.running;
  }
  public A withRunning(Integer running) {
    this.running=running; return (A) this;
  }
  public boolean hasRunning() {
    return this.running != null;
  }
  public String getState() {
    return this.state;
  }
  public A withState(String state) {
    this.state=state; return (A) this;
  }
  public boolean hasState() {
    return this.state != null;
  }
  public Integer getUnknown() {
    return this.unknown;
  }
  public A withUnknown(Integer unknown) {
    this.unknown=unknown; return (A) this;
  }
  public boolean hasUnknown() {
    return this.unknown != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    QueueStatusFluent that = (QueueStatusFluent) o;
    if (!java.util.Objects.equals(inqueue, that.inqueue)) return false;

    if (!java.util.Objects.equals(pending, that.pending)) return false;

    if (!java.util.Objects.equals(running, that.running)) return false;

    if (!java.util.Objects.equals(state, that.state)) return false;

    if (!java.util.Objects.equals(unknown, that.unknown)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(inqueue,  pending,  running,  state,  unknown,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (inqueue != null) { sb.append("inqueue:"); sb.append(inqueue + ","); }
    if (pending != null) { sb.append("pending:"); sb.append(pending + ","); }
    if (running != null) { sb.append("running:"); sb.append(running + ","); }
    if (state != null) { sb.append("state:"); sb.append(state + ","); }
    if (unknown != null) { sb.append("unknown:"); sb.append(unknown); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> volcano-model-v1beta1-6.9.1-sources.jar: io/fabric8/volcano/scheduling/v1beta1/QueueStatusFluent.java <==
package io.fabric8.volcano.scheduling.v1beta1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class QueueStatusFluent<A extends QueueStatusFluent<A>> extends BaseFluent<A>{
  public QueueStatusFluent() {
  }
  
  public QueueStatusFluent(QueueStatus instance) {
    this.copyInstance(instance);
  }
  private Integer inqueue;
  private Integer pending;
  private Integer running;
  private String state;
  private Integer unknown;
  
  protected void copyInstance(QueueStatus instance) {
    instance = (instance != null ? instance : new QueueStatus());
    if (instance != null) {
          this.withInqueue(instance.getInqueue());
          this.withPending(instance.getPending());
          this.withRunning(instance.getRunning());
          this.withState(instance.getState());
          this.withUnknown(instance.getUnknown());
          this.withInqueue(instance.getInqueue());
          this.withPending(instance.getPending());
          this.withRunning(instance.getRunning());
          this.withState(instance.getState());
          this.withUnknown(instance.getUnknown());
        }
  }
  
  public Integer getInqueue() {
    return this.inqueue;
  }
  
  public A withInqueue(Integer inqueue) {
    this.inqueue = inqueue;
    return (A) this;
  }
  
  public boolean hasInqueue() {
    return this.inqueue != null;
  }
  
  public Integer getPending() {
    return this.pending;
  }
  
  public A withPending(Integer pending) {
    this.pending = pending;
    return (A) this;
  }
  
  public boolean hasPending() {
    return this.pending != null;
  }
  
  public Integer getRunning() {
    return this.running;
  }
  
  public A withRunning(Integer running) {
    this.running = running;
    return (A) this;
  }
  
  public boolean hasRunning() {
    return this.running != null;
  }
  
  public String getState() {
    return this.state;
  }
  
  public A withState(String state) {
    this.state = state;
    return (A) this;
  }
  
  public boolean hasState() {
    return this.state != null;
  }
  
  public Integer getUnknown() {
    return this.unknown;
  }
  
  public A withUnknown(Integer unknown) {
    this.unknown = unknown;
    return (A) this;
  }
  
  public boolean hasUnknown() {
    return this.unknown != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    QueueStatusFluent that = (QueueStatusFluent) o;
    if (!java.util.Objects.equals(inqueue, that.inqueue)) return false;
    if (!java.util.Objects.equals(pending, that.pending)) return false;
    if (!java.util.Objects.equals(running, that.running)) return false;
    if (!java.util.Objects.equals(state, that.state)) return false;
    if (!java.util.Objects.equals(unknown, that.unknown)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(inqueue,  pending,  running,  state,  unknown,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (inqueue != null) { sb.append("inqueue:"); sb.append(inqueue + ","); }
    if (pending != null) { sb.append("pending:"); sb.append(pending + ","); }
    if (running != null) { sb.append("running:"); sb.append(running + ","); }
    if (state != null) { sb.append("state:"); sb.append(state + ","); }
    if (unknown != null) { sb.append("unknown:"); sb.append(unknown); }
    sb.append("}");
    return sb.toString();
  }
  

}
